"""
URL configuration for app project.

The `urlpatterns` list routes URLs to views. For more information please see:
    https://docs.djangoproject.com/en/4.2/topics/http/urls/
Examples:
Function views
    1. Add an import:  from my_app import views
    2. Add app URL to urlpatterns:  path('', views.home, name='home')
Class-based views
    1. Add an import:  from other_app.views import Home
    2. Add app URL to urlpatterns:  path('', Home.as_view(), name='home')
Including another URLconf
    1. Import the include() function: from django.urls import include, path
    2. Add app URL to urlpatterns:  path('blog/', include('blog.urls'))
"""
import logging

import yaml
from django.conf import settings
from django.conf.urls.static import static
from django.urls import path, include
from rest_framework import routers

from app.settings import config
from utils.jwt import TokenObtainPairView, TokenRefreshView

from drf_yasg.views import get_schema_view
from drf_yasg import openapi

logger = logging.getLogger()

schema_view = get_schema_view(
    openapi.Info(
        title="测试工程API",
        default_version="v1.0",
        description="测试工程接口文档",
        terms_of_service="#",
        contact=openapi.Contact(email=""),
        license=openapi.License(name=""),
    ),
    public=True,
    permission_classes=(),
)

router = routers.DefaultRouter()

urlpatterns = [
    path("api/token/", TokenObtainPairView.as_view(), name="token_obtain_pair"),
    path("api/token/refresh/", TokenRefreshView.as_view(), name="token_refresh"),
    path("api/", include("system.urls")),
    path("api/", include("asset.urls")),
    path("api/", include("validation.urls")),
    path("api/", include("migrate.urls")),
]
if settings.DEBUG:
    ext_urlpatterns = [
        path(r"^api-auth/", include("rest_framework.urls", namespace="rest_framework")),
        # 配置drf-yasg路由
        path("^swagger(?P<format>\.json|\.yaml)$", schema_view.without_ui(cache_timeout=0), name="schema-json"),
        path("swagger", schema_view.with_ui("swagger", cache_timeout=0), name="schema-swagger-ui"),
        path("redoc/", schema_view.with_ui("redoc", cache_timeout=0), name="schema-redoc"),
    ]
    urlpatterns += ext_urlpatterns
    urlpatterns += static(settings.STATIC_URL, document_root=settings.STATIC_ROOT)
    logger.info(f'加载的配置:\n{yaml.dump(config)}')
