import os
import sys

import django
import eventlet
import socketio

sys.path.append('../')
from utils.util import verify_auth

os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'app.settings')
django.setup()
from rest_framework_simplejwt.authentication import JWTAuthentication

sio = socketio.Server(async_mode='eventlet')
app = socketio.WSGIApp(sio)


@sio.event
def connect(sid, environ, auth):
    if auth:  # 后端client推送接收使用的认证
        token, timestamp = auth
        if not verify_auth(token, timestamp):
            raise ConnectionRefusedError('令牌无效或已过期')
    else:  # 前端client推送接收使用的认证
        jwt_auth = JWTAuthentication()
        authorization = None
        for header in environ['headers_raw']:
            if header[0] == 'Authorization':
                authorization = header[1]
        if authorization is None:
            raise ConnectionRefusedError('令牌无效或已过期')
        raw_token = jwt_auth.get_raw_token(authorization.encode('utf-8'))
        if raw_token is None:
            raise ConnectionRefusedError('令牌无效或已过期')
        try:
            jwt_auth.get_validated_token(raw_token)
        except:
            raise ConnectionRefusedError('令牌无效或已过期')


@sio.event
def disconnect(sid):
    pass


@sio.event
def on_join(sid, room):
    sio.enter_room(sid, room)


@sio.event
def on_leave(sid, room):
    sio.leave_room(sid, room)


@sio.event
def push_backup_by_task(sid, data: dict):
    """
    推送备份结果
    """
    sio.emit('pull_backup_by_task', data, room=data['room'])


@sio.event
def push_restore_by_task(sid, data: dict):
    """
    推送还原结果
    """
    sio.emit('pull_restore_by_task', data, room=data['room'])


@sio.event
def push_migrate_by_task(sid, data: dict):
    """
    推送迁移结果
    """
    sio.emit('pull_migrate_by_task', data, room=data['room'])


if __name__ == '__main__':
    eventlet.wsgi.server(eventlet.listen(('0.0.0.0', 9100)), app)
