from datetime import datetime

from django.utils import timezone
from rest_framework.request import Request
from rest_framework.response import Response
from rest_framework_simplejwt.exceptions import TokenError, InvalidToken
from rest_framework_simplejwt.settings import api_settings
from rest_framework_simplejwt.views import TokenViewBase

from app.settings import SIMPLE_JWT
from utils.response import SuccessResponse


class TokenObtainPairView(TokenViewBase):
    """
    使用用户名和密码获取token
    """
    _serializer_class = api_settings.TOKEN_OBTAIN_SERIALIZER

    def post(self, request: Request, *args, **kwargs) -> Response:
        serializer = self.get_serializer(data=request.data)
        try:
            serializer.is_valid(raise_exception=True)
        except TokenError as e:
            raise InvalidToken()
        data = serializer.validated_data
        data['user_id'] = serializer.user.id
        data['username'] = serializer.user.username
        data['access_token_endtime'] = int((datetime.now() + SIMPLE_JWT['ACCESS_TOKEN_LIFETIME']).timestamp())
        data['refresh_token_endtime'] = int((datetime.now() + SIMPLE_JWT['REFRESH_TOKEN_LIFETIME']).timestamp())
        serializer.user.last_login = timezone.now()  # 更新最后登录时间
        serializer.user.save(update_fields=["last_login"])
        return SuccessResponse(data)


class TokenRefreshView(TokenViewBase):
    """
    使用refresh获取token
    """
    _serializer_class = api_settings.TOKEN_REFRESH_SERIALIZER

    def post(self, request: Request, *args, **kwargs) -> Response:
        serializer = self.get_serializer(data=request.data)
        try:
            serializer.is_valid(raise_exception=True)
        except TokenError as e:
            raise InvalidToken()
        return SuccessResponse(serializer.validated_data)
